@@ -28,13 +28,23 @@ class MockHttp(object):
         self.headers = headers or {}
         self.add_certificate = mock.Mock(return_value=None)
 
-    def request(self, url, method='GET', body=None, headers=None, **kwargs):
-        self.requests.append((method, url, body, headers, kwargs))
+    def request(
+        self,
+        url,
+        method="GET",
+        body=None,
+        headers=None,
+        redirections=httplib2.DEFAULT_MAX_REDIRECTS,
+        connection_type=None,
+    ):
+        self.requests.append(
+            (method, url, body, headers, redirections, connection_type)
+        )
         return self.responses.pop(0)
 
 
 class MockResponse(object):
-    def __init__(self, status=http_client.OK, data=b''):
+    def __init__(self, status=http_client.OK, data=b""):
         self.status = status
         self.data = data
 
@@ -49,13 +59,19 @@ class TestRequestResponse(compliance.RequestResponseTests):
         return google_auth_httplib2.Request(http)
 
     def test_timeout(self):
-        url = 'http://example.com'
+        url = "http://example.com"
         http = MockHttp(responses=[MockResponse()])
         request = google_auth_httplib2.Request(http)
-        request(url=url, method='GET', timeout=5)
+        request(url=url, method="GET", timeout=5)
 
         assert http.requests[0] == (
-            'GET', url, None, None, {})
+            "GET",
+            url,
+            None,
+            None,
+            httplib2.DEFAULT_MAX_REDIRECTS,
+            None,
+        )
 
 
 def test__make_default_http():
@@ -64,32 +80,37 @@ def test__make_default_http():
 
 
 class MockCredentials(object):
-    def __init__(self, token='token'):
+    def __init__(self, token="token"):
         self.token = token
 
     def apply(self, headers):
-        headers['authorization'] = self.token
+        headers["authorization"] = self.token
 
     def before_request(self, request, method, url, headers):
         self.apply(headers)
 
     def refresh(self, request):
-        self.token += '1'
+        self.token += "1"
 
 
 class TestAuthorizedHttp(object):
-    TEST_URL = 'http://example.com'
+    TEST_URL = "http://example.com"
 
     def test_authed_http_defaults(self):
-        authed_http = google_auth_httplib2.AuthorizedHttp(
-            mock.sentinel.credentials)
+        authed_http = google_auth_httplib2.AuthorizedHttp(mock.sentinel.credentials)
 
         assert authed_http.credentials == mock.sentinel.credentials
         assert isinstance(authed_http.http, httplib2.Http)
 
+    def test_close(self):
+        with mock.patch("httplib2.Http.close", autospec=True) as close:
+            authed_http = google_auth_httplib2.AuthorizedHttp(mock.sentinel.credentials)
+            authed_http.close()
+
+            close.assert_called_once()
+
     def test_connections(self):
-        authed_http = google_auth_httplib2.AuthorizedHttp(
-            mock.sentinel.credentials)
+        authed_http = google_auth_httplib2.AuthorizedHttp(mock.sentinel.credentials)
 
         assert authed_http.connections == authed_http.http.connections
 
@@ -97,9 +118,7 @@ class TestAuthorizedHttp(object):
         assert authed_http.http.connections == mock.sentinel.connections
 
     def test_follow_redirects(self):
-        auth_http = google_auth_httplib2.AuthorizedHttp(
-            mock.sentinel.credentials
-        )
+        auth_http = google_auth_httplib2.AuthorizedHttp(mock.sentinel.credentials)
 
         assert auth_http.follow_redirects == auth_http.http.follow_redirects
 
@@ -108,24 +127,27 @@ class TestAuthorizedHttp(object):
         assert auth_http.http.follow_redirects == mock_follow_redirects
 
     def test_timeout(self):
-        authed_http = google_auth_httplib2.AuthorizedHttp(
-            mock.sentinel.credentials
-        )
+        authed_http = google_auth_httplib2.AuthorizedHttp(mock.sentinel.credentials)
 
         assert authed_http.timeout == authed_http.http.timeout
 
         authed_http.timeout = mock.sentinel.timeout
         assert authed_http.http.timeout == mock.sentinel.timeout
 
+    def test_redirect_codes(self):
+        authed_http = google_auth_httplib2.AuthorizedHttp(mock.sentinel.credentials)
+
+        assert authed_http.redirect_codes == authed_http.http.redirect_codes
+
+        authed_http.redirect_codes = mock.sentinel.redirect_codes
+        assert authed_http.http.redirect_codes == mock.sentinel.redirect_codes
+
     def test_add_certificate(self):
         authed_http = google_auth_httplib2.AuthorizedHttp(
-            mock.sentinel.credentials,
-            http=MockHttp(MockResponse())
+            mock.sentinel.credentials, http=MockHttp(MockResponse())
         )
 
-        authed_http.add_certificate(
-            "key", "cert", "domain", password="password"
-        )
+        authed_http.add_certificate("key", "cert", "domain", password="password")
         authed_http.http.add_certificate.assert_called_once_with(
             "key", "cert", "domain", password="password"
         )
@@ -136,7 +158,8 @@ class TestAuthorizedHttp(object):
         mock_http = MockHttp([mock_response])
 
         authed_http = google_auth_httplib2.AuthorizedHttp(
-            mock_credentials, http=mock_http)
+            mock_credentials, http=mock_http
+        )
 
         response, data = authed_http.request(self.TEST_URL)
 
@@ -145,18 +168,27 @@ class TestAuthorizedHttp(object):
         assert mock_credentials.before_request.called
         assert not mock_credentials.refresh.called
         assert mock_http.requests == [
-            ('GET', self.TEST_URL, None, {'authorization': 'token'}, {})]
+            (
+                "GET",
+                self.TEST_URL,
+                None,
+                {"authorization": "token"},
+                httplib2.DEFAULT_MAX_REDIRECTS,
+                None,
+            )
+        ]
 
     def test_request_refresh(self):
         mock_credentials = mock.Mock(wraps=MockCredentials())
         mock_final_response = MockResponse(status=http_client.OK)
         # First request will 401, second request will succeed.
-        mock_http = MockHttp([
-            MockResponse(status=http_client.UNAUTHORIZED),
-            mock_final_response])
+        mock_http = MockHttp(
+            [MockResponse(status=http_client.UNAUTHORIZED), mock_final_response]
+        )
 
         authed_http = google_auth_httplib2.AuthorizedHttp(
-            mock_credentials, http=mock_http)
+            mock_credentials, http=mock_http
+        )
 
         response, data = authed_http.request(self.TEST_URL)
 
@@ -165,28 +197,87 @@ class TestAuthorizedHttp(object):
         assert mock_credentials.before_request.call_count == 2
         assert mock_credentials.refresh.called
         assert mock_http.requests == [
-            ('GET', self.TEST_URL, None, {'authorization': 'token'}, {}),
-            ('GET', self.TEST_URL, None, {'authorization': 'token1'}, {})]
+            (
+                "GET",
+                self.TEST_URL,
+                None,
+                {"authorization": "token"},
+                httplib2.DEFAULT_MAX_REDIRECTS,
+                None,
+            ),
+            (
+                "GET",
+                self.TEST_URL,
+                None,
+                {"authorization": "token1"},
+                httplib2.DEFAULT_MAX_REDIRECTS,
+                None,
+            ),
+        ]
 
     def test_request_stream_body(self):
         mock_credentials = mock.Mock(wraps=MockCredentials())
         mock_response = MockResponse()
         # Refresh is needed to cover the resetting of the body position.
-        mock_http = MockHttp([
-            MockResponse(status=http_client.UNAUTHORIZED),
-            mock_response])
+        mock_http = MockHttp(
+            [MockResponse(status=http_client.UNAUTHORIZED), mock_response]
+        )
 
-        body = six.StringIO('body')
+        body = six.StringIO("body")
         body.seek(1)
 
         authed_http = google_auth_httplib2.AuthorizedHttp(
-            mock_credentials, http=mock_http)
+            mock_credentials, http=mock_http
+        )
 
-        response, data = authed_http.request(
-            self.TEST_URL, method='POST', body=body)
+        response, data = authed_http.request(self.TEST_URL, method="POST", body=body)
 
         assert response == mock_response
         assert data == mock_response.data
         assert mock_http.requests == [
-            ('POST', self.TEST_URL, body, {'authorization': 'token'}, {}),
-            ('POST', self.TEST_URL, body, {'authorization': 'token1'}, {})]
+            (
+                "POST",
+                self.TEST_URL,
+                body,
+                {"authorization": "token"},
+                httplib2.DEFAULT_MAX_REDIRECTS,
+                None,
+            ),
+            (
+                "POST",
+                self.TEST_URL,
+                body,
+                {"authorization": "token1"},
+                httplib2.DEFAULT_MAX_REDIRECTS,
+                None,
+            ),
+        ]
+
+    def test_request_positional_args(self):
+        """Verifies that clients can pass args to request as positioanls."""
+        mock_credentials = mock.Mock(wraps=MockCredentials())
+        mock_response = MockResponse()
+        mock_http = MockHttp([mock_response])
+
+        authed_http = google_auth_httplib2.AuthorizedHttp(
+            mock_credentials, http=mock_http
+        )
+
+        response, data = authed_http.request(
+            self.TEST_URL, "GET", None, None, httplib2.DEFAULT_MAX_REDIRECTS, None
+        )
+
+        assert response == mock_response
+        assert data == mock_response.data
+        assert mock_credentials.before_request.called
+        assert not mock_credentials.refresh.called
+        assert mock_http.requests == [
+            (
+                "GET",
+                self.TEST_URL,
+                None,
+                {"authorization": "token"},
+                httplib2.DEFAULT_MAX_REDIRECTS,
+                None,
+            )
+        ]
